@@ -12,8 +12,7 @@ def command_line_entrypoint():
 	parser.add_argument(
 		'folders',
 		metavar='DIR',
-		type=str,
-		nargs='*',
+		nargs='+',
 		help='The ROM folders to sort (absolute)'
 	)
 
